package org.zeroturnaround.javarebel.integration.spring;

import java.io.File;
import org.springframework.beans.factory.support.BeanDefinitionReader;
import org.springframework.core.io.Resource;
import org.zeroturnaround.javarebel.LoggerFactory;

class XMLBeanDefinitionResource {
  private long lastModified;
  private Resource xmlRes;
  private File xmlFile;
  private BeanDefinitionReader bdr;

  public XMLBeanDefinitionResource(BeanDefinitionReader bdr, Resource xmlRes, File xmlFile) { 
    this.bdr = bdr;
    this.xmlFile = xmlFile;
    this.xmlRes = xmlRes;

    lastModified = xmlFile.lastModified();   
  }

  public synchronized void reload() {
    lastModified = xmlFile.lastModified();

    LoggerFactory.getInstance().echo(
        "JavaRebel-Spring: Reloading Spring bean definitions in '" + xmlFile + "'.");

    try {
      bdr.loadBeanDefinitions(xmlRes);
    }
    catch (Throwable e) {
      if (e instanceof Error) throw (Error) e;
      LoggerFactory.getInstance().error(e);
    }
  }


  public synchronized void checkAndReload() {
    if (xmlFile.lastModified() > lastModified) {
      reload();
    }
  }
}